==> haskell-say-0.1.0.1-319-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-say.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 say
version:              0.1.0.1
visibility:           public
id:                   say-0.1.0.1-62SfEFq4VPa2YEPizrVBJ9
key:                  say-0.1.0.1-62SfEFq4VPa2YEPizrVBJ9
license:              MIT
copyright:            2016-2018 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/say#readme
synopsis:             Send textual messages to a Handle in a thread-friendly way
description:
    Please see the README and documentation at <https://www.stackage.org/package/say>

category:             Text
abi:                  c21ab9ef14ceb88230bb77bda7149f3b
exposed:              True
exposed-modules:      Say
hidden-modules:       Paths_say
import-dirs:          /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-say
hs-libraries:         HSsay-0.1.0.1-62SfEFq4VPa2YEPizrVBJ9
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-say/html/say.haddock
haddock-html:         /usr/share/doc/haskell-say/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-say-0.1.0.1-320-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-say.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 say
version:              0.1.0.1
visibility:           public
id:                   say-0.1.0.1-FXw4WCijgxm8qY3ifoUNbf
key:                  say-0.1.0.1-FXw4WCijgxm8qY3ifoUNbf
license:              MIT
copyright:            2016-2018 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/say#readme
synopsis:             Send textual messages to a Handle in a thread-friendly way
description:
    Please see the README and documentation at <https://www.stackage.org/package/say>

category:             Text
abi:                  5bb795b4cfdd7c221f0bdc01c1ff8420
exposed:              True
exposed-modules:      Say
hidden-modules:       Paths_say
import-dirs:          /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-say
hs-libraries:         HSsay-0.1.0.1-FXw4WCijgxm8qY3ifoUNbf
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-say/html/say.haddock
haddock-html:         /usr/share/doc/haskell-say/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
